@@ -19,7 +19,7 @@ use Image::ExifTool qw(:DataAccess :Utils);
 use Image::ExifTool::Exif;
 use Image::ExifTool::ASF;   # for GetGUID()
 
-$VERSION = '1.24';
+$VERSION = '1.25';
 
 sub ProcessFPX($$);
 sub ProcessFPXR($$$);
@@ -298,7 +298,8 @@ my %fpxFileType = (
         "file allocation table" (FAT).  No wonder this image format never became
         popular.  However, some of the structures used in FlashPix streams are part
         of the EXIF specification, and are still being used in the APP2 FPXR segment
-        of JPEG images by some digital cameras from various manufacturers.
+        of JPEG images by some digital cameras from manufacturers such as FujiFilm,
+        Hewlett-Packard, Kodak and Sanyo.
 
         ExifTool extracts FlashPix information from both FPX images and the APP2
         FPXR segment of JPEG images.  As well, FlashPix information is extracted
@@ -1693,11 +1694,11 @@ sub ProcessFPX($$)
     }
     if ($verbose) {
         print $out "  FAT [",length($fat)," bytes]:\n";
-        Image::ExifTool::HexDump(\$fat, undef, %dumpParms) if $verbose > 2;
+        HexDump(\$fat, undef, %dumpParms) if $verbose > 2;
         print $out "  Mini-FAT [",length($miniFat)," bytes]:\n";
-        Image::ExifTool::HexDump(\$miniFat, undef, %dumpParms) if $verbose > 2;
+        HexDump(\$miniFat, undef, %dumpParms) if $verbose > 2;
         print $out "  Directory [",length($dir)," bytes]:\n";
-        Image::ExifTool::HexDump(\$dir, undef, %dumpParms) if $verbose > 2;
+        HexDump(\$dir, undef, %dumpParms) if $verbose > 2;
     }
 #
 # process the directory
@@ -1899,7 +1900,7 @@ JPEG images.
 
 =head1 AUTHOR
 
-Copyright 2003-2014, Phil Harvey (phil at owl.phy.queensu.ca)
+Copyright 2003-2015, Phil Harvey (phil at owl.phy.queensu.ca)
 
 This library is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
